#!/usr/bin/python

# gpsman-background, utility for GPSMan
# Copyright (C) 2005 Christian Mauduit <ufoot@ufoot.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# http://www.ufoot.org

import sys
import re

GPS_BACKGROUND_PY_DEFAULT="/home/mauduit/cvs/portable-mauduit/perso/sport/gps/gpsman-background/gpsman-background.py"

class Makefile:
    """Builds a Makefile which will later be used to launch gps_background."""
    def __init__(self,source_prefix="",target_prefix="",gps_background_py=""):
        self.source_prefix=source_prefix
        self.target_prefix=target_prefix
        if (gps_background_py):
            self.gps_background_py=gps_background_py
        else:
            self.gps_background_py=GPS_BACKGROUND_PY_DEFAULT
        self.targets={}
    def add_target(self,target,sources):
        """Adds a target to the Makefile. Target is the name of the target file, and source is a tuple containing all the sources files."""
        self.targets[target]=sources
    def write(self):
        """Builds and writes the Makefile down on the disk."""
        repl=re.compile("(\.jpg|jpeg|gif|pnm|bmp)$")
        targets=""
        targets_georef=""
        for target in self.targets.keys():
            targets+="%(prefix)s%(target)s " % {"prefix": self.target_prefix, "target":target}
            targets_georef+="%(prefix)s%(target_georef)s " % {"prefix": self.target_prefix, "target_georef": repl.sub(".georef",target)}
        f=open("Makefile","w")
        #f=sys.stdout
        f.write("all : %(targets)s\n\nclean : \n\trm -f %(targets)s %(targets_georef)s\n\n" % {"targets":targets, "targets_georef":targets_georef})
        repl=re.compile("(\.jpg|jpeg|gif|pnm|bmp)$")
        for target in self.targets.keys():
            sources=""
            sources_txt=""
            for source in self.targets[target]:
                sources+="%(prefix)s%(source)s " % {"prefix": self.source_prefix, "source":source}
                sources_txt+="%(prefix)s%(source_txt)s " % {"prefix": self.source_prefix, "source_txt": repl.sub(".txt",source)}
            f.write("%(prefix)s%(target)s : %(sources)s %(sources_txt)s\n\t%(gps_background_py)s %(prefix)s%(target)s %(sources)s\n\n" % {"prefix":self.target_prefix,"target":target, "sources":sources, "sources_txt": sources_txt, "gps_background_py":self.gps_background_py})
        f.close()
        pass

m=Makefile("/home/mauduit/data/cartes/scan_ign/","/home/mauduit/data/cartes/gpsman_background/")

m.add_target("Argenteuil-test.jpg",
             ("2314OT-Paris/2314OT-1a.300dpi.jpg",
              "2314OT-Paris/2314OT-1b.300dpi.jpg",
              "2314OT-Paris/2314OT-2a.300dpi.jpg",
              "2314OT-Paris/2314OT-2b.300dpi.jpg"))

m.add_target("23140T-Paris.jpg",
             ("2314OT-Paris/2314OT-1a.300dpi.jpg",
              "2314OT-Paris/2314OT-1b.300dpi.jpg",
              "2314OT-Paris/2314OT-1c.300dpi.jpg",
              "2314OT-Paris/2314OT-1d.300dpi.jpg",
              "2314OT-Paris/2314OT-1e.300dpi.jpg",
              "2314OT-Paris/2314OT-1f.300dpi.jpg",
              "2314OT-Paris/2314OT-2a.300dpi.jpg",
              "2314OT-Paris/2314OT-2b.300dpi.jpg",
              "2314OT-Paris/2314OT-2c.300dpi.jpg",
              "2314OT-Paris/2314OT-2d.300dpi.jpg",
              "2314OT-Paris/2314OT-2e.300dpi.jpg",
              "2314OT-Paris/2314OT-2f.300dpi.jpg",
              "2314OT-Paris/2314OT-3a.300dpi.jpg",
              "2314OT-Paris/2314OT-3b.300dpi.jpg",
              "2314OT-Paris/2314OT-3c.300dpi.jpg",
              "2314OT-Paris/2314OT-3d.300dpi.jpg",
              "2314OT-Paris/2314OT-3e.300dpi.jpg",
              "2314OT-Paris/2314OT-3f.300dpi.jpg",
              "2314OT-Paris/2314OT-4a.300dpi.jpg",
              "2314OT-Paris/2314OT-4b.300dpi.jpg",
              "2314OT-Paris/2314OT-4c.300dpi.jpg",
              "2314OT-Paris/2314OT-4d.300dpi.jpg",
              "2314OT-Paris/2314OT-4e.300dpi.jpg",
              "2314OT-Paris/2314OT-4f.300dpi.jpg"))

m.write()
    
